#!/bin/sh
# the next line restarts using wish\
exec wish "$0" "$@" 

if {![info exists vTcl(sourcing)]} {
    switch $tcl_platform(platform) {
	windows {
	}
	default {
	    option add *Scrollbar.width 10
	}
    }
    
}
############################
# vTcl Code to Load Stock Fonts


if {![info exist vTcl(sourcing)]} {
set vTcl(fonts,counter) 0
proc vTcl:font:add_font {font_descr font_type newkey} {
     global vTcl

     incr vTcl(fonts,counter)
     set newfont [eval font create $font_descr]

     lappend vTcl(fonts,objects) $newfont

     # each font has its unique key so that when a project is
     # reloaded, the key is used to find the font description

     if {$newkey == ""} {
          set newkey vTcl:font$vTcl(fonts,counter)

          # let's find an unused font key
          while {[vTcl:font:get_font $newkey] != ""} {
             incr vTcl(fonts,counter)
             set newkey vTcl:font$vTcl(fonts,counter)
          }
     }

     set vTcl(fonts,$newfont,type)                      $font_type
     set vTcl(fonts,$newfont,key)                       $newkey
     set vTcl(fonts,$vTcl(fonts,$newfont,key),object)   $newfont

     lappend vTcl(fonts,$font_type) $newfont

     # in case caller needs it
     return $newfont
}

proc vTcl:font:get_font {key} {
    global vTcl
    if {[info exists vTcl(fonts,$key,object)]} then {
        return $vTcl(fonts,$key,object)
    } else {
        return ""
    }
}

vTcl:font:add_font \
    "-family helvetica -size 12 -weight normal -slant roman -underline 0 -overstrike 0" \
    stock \
    vTcl:font1
}
#############################################################################
# Visual Tcl v1.51 Project
#

#################################
# VTCL LIBRARY PROCEDURES
#

if {![info exists vTcl(sourcing)]} {
proc Window {args} {
    global vTcl
    set cmd     [lindex $args 0]
    set name    [lindex $args 1]
    set newname [lindex $args 2]
    set rest    [lrange $args 3 end]
    if {$name == "" || $cmd == ""} { return }
    if {$newname == ""} { set newname $name }
    if {$name == "."} { wm withdraw $name; return }
    set exists [winfo exists $newname]
    switch $cmd {
        show {
            if {$exists} {
                wm deiconify $newname
            } elseif {[info procs vTclWindow$name] != ""} {
                eval "vTclWindow$name $newname $rest"
            }
            if {[wm state $newname] == "normal"} {
                vTcl:FireEvent $newname <<Show>>
            }
        }
        hide    {
            if {$exists} {
                wm withdraw $newname
                vTcl:FireEvent $newname <<Hide>>
                return}
        }
        iconify { if $exists {wm iconify $newname; return} }
        destroy { if $exists {destroy $newname; return} }
    }
}
}

if {![info exists vTcl(sourcing)]} {
proc {vTcl:DefineAlias} {target alias widgetProc top_or_alias cmdalias} {
    global widget

    set widget($alias) $target
    set widget(rev,$target) $alias

    if {$cmdalias} {
        interp alias {} $alias {} $widgetProc $target
    }

    if {$top_or_alias != ""} {
        set widget($top_or_alias,$alias) $target

        if {$cmdalias} {
            interp alias {} $top_or_alias.$alias {} $widgetProc $target
        }
    }
}

proc {vTcl:DoCmdOption} {target cmd} {
    ## menus are considered toplevel windows
    set parent $target
    while {[winfo class $parent] == "Menu"} {
        set parent [winfo parent $parent]
    }

    regsub -all {\%widget} $cmd $target cmd
    regsub -all {\%top} $cmd [winfo toplevel $parent] cmd

    uplevel #0 [list eval $cmd]
}

proc {vTcl:FireEvent} {target event} {
    foreach bindtag [bindtags $target] {
        set tag_events [bind $bindtag]
        set stop_processing 0
        foreach tag_event $tag_events {
            if {$tag_event == $event} {
                set bind_code [bind $bindtag $tag_event]
                regsub -all %W $bind_code $target bind_code
                set result [catch {uplevel #0 $bind_code} errortext]
                if {$result == 3} {
                    # break exception, stop processing
                    set stop_processing 1
                } elseif {$result != 0} {
                    bgerror $errortext
                }
                break
            }
        }
        if {$stop_processing} {break}
    }
}

proc {vTcl:Toplevel:WidgetProc} {w args} {
    if {[llength $args] == 0} {
        return -code error "wrong # args: should be \"$w option ?arg arg ...?\""
    }

    ## The first argument is a switch, they must be doing a configure.
    if {[string index $args 0] == "-"} {
        set command configure

        ## There's only one argument, must be a cget.
        if {[llength $args] == 1} {
            set command cget
        }
    } else {
        set command [lindex $args 0]
        set args [lrange $args 1 end]
    }

    switch -- $command {
        "hide" -
        "Hide" {
            Window hide $w
        }

        "show" -
        "Show" {
            Window show $w
        }

        "ShowModal" {
            Window show $w
            raise $w
            grab $w
            tkwait window $w
            grab release $w
        }

        default {
            eval $w $command $args
        }
    }
}

proc {vTcl:WidgetProc} {w args} {
    if {[llength $args] == 0} {
        return -code error "wrong # args: should be \"$w option ?arg arg ...?\""
    }

    ## The first argument is a switch, they must be doing a configure.
    if {[string index $args 0] == "-"} {
        set command configure

        ## There's only one argument, must be a cget.
        if {[llength $args] == 1} {
            set command cget
        }
    } else {
        set command [lindex $args 0]
        set args [lrange $args 1 end]
    }

    eval $w $command $args
}

proc {vTcl:toplevel} {args} {
    uplevel #0 eval toplevel $args
    set target [lindex $args 0]
    namespace eval ::$target {}
}
}

if {[info exists vTcl(sourcing)]} {
proc vTcl:project:info {} {
    namespace eval ::widgets::.top32 {
        array set save {-menu 1}
    }
    namespace eval ::widgets::.top32.fra45 {
        array set save {-borderwidth 1 -cursor 1 -height 1 -relief 1 -width 1}
    }
    namespace eval ::widgets::.top32.fra45.tex46 {
        array set save {-background 1 -height 1 -width 1 -wrap 1 -xscrollcommand 1 -yscrollcommand 1}
    }
    namespace eval ::widgets::.top32.fra45.scr47 {
        array set save {-command 1 -orient 1 -width 1}
    }
    namespace eval ::widgets::.top32.fra45.scr48 {
        array set save {-command 1 -width 1}
    }
    namespace eval ::widgets::.top32.fra45.lab49 {
        array set save {-text 1 -width 1}
    }
    namespace eval ::widgets::.top32.fra45.but32 {
        array set save {-command 1 -height 1 -text 1 -width 1}
    }
    namespace eval ::widgets::.top32.fra45.ent33 {
        array set save {-background 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::.top32.fra45.but48 {
        array set save {-command 1 -height 1 -text 1 -width 1}
    }
    namespace eval ::widgets::.top32.fra66 {
        array set save {-borderwidth 1 -height 1 -relief 1 -width 1}
    }
    namespace eval ::widgets::.top32.fra66.lab67 {
        array set save {-text 1}
    }
    namespace eval ::widgets::.top32.fra66.ent69 {
        array set save {-background 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::.top32.fra66.lab70 {
        array set save {-height 1 -text 1}
    }
    namespace eval ::widgets::.top32.fra66.ent71 {
        array set save {-background 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::.top32.fra66.ent72 {
        array set save {-background 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::.top32.fra66.lab73 {
        array set save {-height 1 -text 1 -width 1}
    }
    namespace eval ::widgets::.top32.fra66.ent74 {
        array set save {-background 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::.top32.fra66.lab75 {
        array set save {-text 1}
    }
    namespace eval ::widgets::.top32.fra66.but51 {
        array set save {-command 1 -height 1 -text 1 -width 1}
    }
    namespace eval ::widgets::.top32.fra66.but52 {
        array set save {-command 1 -height 1 -text 1 -width 1}
    }
    namespace eval ::widgets::.top32.fra76 {
        array set save {-borderwidth 1 -height 1 -relief 1 -width 1}
    }
    namespace eval ::widgets::.top32.fra76.ent77 {
        array set save {-background 1 -cursor 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::.top32.fra76.ent78 {
        array set save {-background 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::.top32.fra76.lab79 {
        array set save {-height 1 -text 1 -width 1}
    }
    namespace eval ::widgets::.top32.fra76.lab79.ent37 {
        array set save {-background 1 -textvariable 1}
    }
    namespace eval ::widgets::.top32.fra76.lab80 {
        array set save {-height 1 -text 1 -width 1}
    }
    namespace eval ::widgets::.top32.fra76.che97 {
        array set save {-height 1 -text 1 -variable 1 -width 1}
    }
    namespace eval ::widgets::.top32.fra86 {
        array set save {-borderwidth 1 -cursor 1 -height 1 -relief 1 -width 1}
    }
    namespace eval ::widgets::.top32.fra86.ent88 {
        array set save {-background 1 -state 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::.top32.fra86.che95 {
        array set save {-text 1 -variable 1}
    }
    namespace eval ::widgets::.top32.fra86.che96 {
        array set save {-height 1 -text 1 -variable 1}
    }
    namespace eval ::widgets::.top32.fra90 {
        array set save {-borderwidth 1 -height 1 -relief 1 -width 1}
    }
    namespace eval ::widgets::.top32.fra90.but91 {
        array set save {-command 1 -cursor 1 -height 1 -text 1 -width 1}
    }
    namespace eval ::widgets::.top32.fra90.ent92 {
        array set save {-background 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::.top32.fra90.but93 {
        array set save {-command 1 -cursor 1 -text 1}
    }
    namespace eval ::widgets::.top32.fra90.ent94 {
        array set save {-background 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::.top32.fra90.but41 {
        array set save {-height 1 -text 1 -width 1}
    }
    namespace eval ::widgets::.top32.fra90.but49 {
        array set save {-command 1 -height 1 -text 1 -width 1}
    }
    namespace eval ::widgets::.top32.fra90.but50 {
        array set save {-command 1 -height 1 -text 1 -width 1}
    }
    namespace eval ::widgets::.top32.fra90.but32 {
        array set save {-command 1 -cursor 1 -height 1 -text 1 -width 1}
    }
    namespace eval ::widgets::.top32.fra90.ent33 {
        array set save {-background 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::.top32.fra90.but34 {
        array set save {-command 1 -cursor 1 -height 1 -text 1 -width 1}
    }
    namespace eval ::widgets::.top32.m32 {
        array set save {-tearoff 1}
    }
    namespace eval ::widgets::.top32.m32.men34 {
        array set save {-font 1 -tearoff 1}
    }
    namespace eval ::widgets::.top32.m32.men35 {
        array set save {-font 1 -tearoff 1}
    }
    namespace eval ::widgets::.top32.m32.men33 {
        array set save {-font 1 -tearoff 1}
    }
    namespace eval ::widgets::.top32.but37 {
        array set save {-command 1 -cursor 1 -height 1 -text 1 -width 1}
    }
    namespace eval ::widgets::.top38 {
        array set save {-menu 1}
    }
    namespace eval ::widgets::.top38.m39 {
        array set save {-tearoff 1}
    }
    namespace eval ::widgets::.top38.lab41 {
        array set save {-height 1 -text 1 -width 1}
    }
    namespace eval ::widgets::.top38.ent42 {
        array set save {-background 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::.top38.lab43 {
        array set save {-height 1 -text 1 -width 1}
    }
    namespace eval ::widgets::.top38.ent44 {
        array set save {-background 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::.top38.but45 {
        array set save {-command 1 -cursor 1 -height 1 -text 1}
    }
    namespace eval ::widgets::.top38.fra47 {
        array set save {-borderwidth 1 -cursor 1 -height 1 -relief 1 -width 1}
    }
    namespace eval ::widgets::.top38.fra47.che48 {
        array set save {-height 1 -text 1 -variable 1}
    }
    namespace eval ::widgets::.top38.fra47.che50 {
        array set save {-command 1 -text 1 -variable 1}
    }
    namespace eval ::widgets::.top38.fra47.che51 {
        array set save {-height 1 -text 1 -variable 1}
    }
    namespace eval ::widgets::.top38.fra47.lab58 {
        array set save {-cursor 1 -text 1}
    }
    namespace eval ::widgets::.top38.fra47.ent60 {
        array set save {-background 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::.top38.fra47.lab61 {
        array set save {-text 1}
    }
    namespace eval ::widgets::.top38.fra47.lab62 {
        array set save {-text 1}
    }
    namespace eval ::widgets::.top38.fra47.lab63 {
        array set save {-text 1}
    }
    namespace eval ::widgets::.top38.fra47.lab64 {
        array set save {-text 1}
    }
    namespace eval ::widgets::.top38.fra47.lab65 {
        array set save {-text 1}
    }
    namespace eval ::widgets::.top38.fra47.ent66 {
        array set save {-background 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::.top38.fra47.ent67 {
        array set save {-background 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::.top38.fra47.ent68 {
        array set save {-background 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::.top38.fra47.ent69 {
        array set save {-background 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::.top38.fra47.ent70 {
        array set save {-background 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::.top38.lab52 {
        array set save {-text 1}
    }
    namespace eval ::widgets::.top38.but53 {
        array set save {-command 1 -cursor 1 -height 1 -text 1}
    }
    namespace eval ::widgets::.top38.but54 {
        array set save {-command 1 -cursor 1 -height 1 -text 1}
    }
    namespace eval ::widgets::.top38.lab55 {
        array set save {-text 1}
    }
    namespace eval ::widgets::.top38.ent56 {
        array set save {-background 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::.top38.but71 {
        array set save {-command 1 -cursor 1 -height 1 -text 1}
    }
    namespace eval ::widgets::.top38.lab35 {
        array set save {-height 1 -text 1 -width 1}
    }
    namespace eval ::widgets::.top38.ent36 {
        array set save {-background 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets_bindings {
        set tagslist {}
    }
}
}
#################################
# USER DEFINED PROCEDURES
#
###########################################################
## Procedure:  clean

proc {clean} {str} {
set start 0
set tempstr ""
set tempstr2 ""
while {[string first \\ $str $start] != -1} {
    set start [string first \\ $str $start]
    set tempstr [string range $str 0 [expr $start - 1]]
    set tempstr1 [string range $str $start [string length $str]]
    append tempstr "\\" $tempstr1
    set str $tempstr
    incr start 2
}

set start 0
set tempstr ""
set tempstr2 ""
while {[string first \" $str $start] != -1} {
    set start [string first \" $str $start]
    set tempstr [string range $str 0 [expr $start - 1]]
    set tempstr1 [string range $str $start [string length $str]]
    append tempstr "\\" $tempstr1
    set str $tempstr
    incr start 2
}

set start 0
set tempstr ""
set tempstr2 ""
while {[string first \` $str $start] != -1} {
    set start [string first \` $str $start]
    set tempstr [string range $str 0 [expr $start - 1]]
    set tempstr1 [string range $str $start [string length $str]]
    append tempstr "\\" $tempstr1
    set str $tempstr
    incr start 2
}
return $str
}
###########################################################
## Procedure:  cleanitems

proc {cleanitems} {str} {
set start 0
set tempstr ""
set tempstr2 ""
while {[string first "\n" $str $start] != -1} {
    set start [string first "\n" $str $start]
    set tempstr [string range $str 0 [expr $start - 1]]
    set tempstr1 [string range $str [expr $start + 1] [string length $str]]
    append tempstr "%" $tempstr1
    set str $tempstr
    incr start 2
}

return [string range $str 0 [expr [string length $str] - 2]]
}
###########################################################
## Procedure:  init
###########################################################
## Procedure:  main

proc {main} {argc argv} {
wm protocol .top32 WM_DELETE_WINDOW {exit}

set tmpdate "date +%D"
set fileid [open |$tmpdate]
set date [read -nonewline $fileid]
set olddir [pwd]
cd ~

if {[file exists ".cdlabelgenfe/config"] == 0} {
    Entry12 delete 0 end
    Entry13 delete 0 end
    Entry14 delete 0 end
    Entry15 delete 0 end
    Entry16 delete 0 end
    Entry17 delete 0 end
    Entry18 delete 0 end
    Entry19 delete 0 end
    Entry20 delete 0 end
    Entry22 delete 0 end
    
    cd "~"
    set mydir [pwd]
    append mydir "/"
    set defsave_dir $mydir
    set defpath "/usr/bin/cdlabelgen"
    set defpreview_with "/usr/X11R6/bin/gv"
    set defcover_image "penguin.eps"
    set defcover_image_sr "0.5"
    set deftray_image ""
    set deftray_image_sr ""
    set defcategory ""
    set defsub_category ""
    set defshow_plaque 1
    set defword_wrap 0
    set defprint_date 1
    set defprint "/usr/bin/lpr"
}
if {[file exists ".cdlabelgenfe/config"] == 1} {
    #read in file
    Entry12 delete 0 end
    Entry13 delete 0 end
    Entry14 delete 0 end
    Entry15 delete 0 end
    Entry16 delete 0 end
    Entry17 delete 0 end
    Entry18 delete 0 end
    Entry19 delete 0 end
    Entry20 delete 0 end
    Entry22 delete 0 end
    
    set fileid [open ".cdlabelgenfe/config"]
    gets $fileid defpath
    gets $fileid defpreview_with
    gets $fileid defsave_dir
    gets $fileid defshow_plaque
    gets $fileid defword_wrap
    gets $fileid defprint_date
    gets $fileid defcategory
    gets $fileid defsub_category
    gets $fileid defcover_image
    gets $fileid defcover_image_sr
    gets $fileid deftray_image
    gets $fileid deftray_image_sr
    gets $fileid defprint
    close $fileid
}

Entry2 delete 0 end
Entry3 delete 0 end
Entry4 delete 0 end
Entry5 delete 0 end
Entry6 delete 0 end
Entry7 delete 0 end
Entry9 delete 0 end
Entry10 delete 0 end
Entry12 delete 0 end
Entry13 delete 0 end
Entry14 delete 0 end
Entry15 delete 0 end
Entry16 delete 0 end
Entry17 delete 0 end
Entry18 delete 0 end
Entry19 delete 0 end
Entry20 delete 0 end
Entry21 delete 0 end
Entry22 delete 0 end
Entry2 insert 0 "$defcategory"
Entry3 insert 0 "$defsub_category"
Entry4 insert 0 "$defcover_image"
Entry5 insert 0 "$defcover_image_sr"
Entry6 insert 0 "$deftray_image"
Entry7 insert 0 "$deftray_image_sr"
Entry9 insert 0 "$defpreview_with"
Entry10 insert 0 "$defsave_dir"
Entry10 insert end "untitled.ps"
Entry12 insert 0 "$defpath"
Entry13 insert 0 "$defpreview_with"
Entry14 insert 0 "$defsave_dir"
Entry15 insert 0 "$defcategory"
Entry16 insert 0 "$defsub_category"
Entry17 insert 0 "$defcover_image"
Entry18 insert 0 "$defcover_image_sr"
Entry19 insert 0 "$deftray_image"
Entry20 insert 0 "$deftray_image_sr"
Entry21 insert 0 "$defprint"
Entry22 insert 0 "$defprint"

if {$defshow_plaque == 1} {
    set show_plaque 1
    Checkbutton7 invoke
    Checkbutton6 invoke
}
if {$defprint_date == 1} {
    set print_date 1
    Checkbutton8 invoke
    Checkbutton4 invoke
}
if {$defword_wrap == 1} {
    set word_wrap 1
    Checkbutton9 invoke
    Checkbutton5 invoke
}


Entry8 insert 0 "$date"

cd $olddir
}

proc init {argc argv} {

}

init $argc $argv

#################################
# VTCL GENERATED GUI PROCEDURES
#

proc vTclWindow. {base {container 0}} {
    if {$base == ""} {
        set base .
    }
    ###################
    # CREATING WIDGETS
    ###################
    if {!$container} {
    wm focusmodel $base passive
    wm geometry $base 1x1+0+0; update
    wm maxsize $base 1009 738
    wm minsize $base 1 1
    wm overrideredirect $base 0
    wm resizable $base 1 1
    wm withdraw $base
    wm title $base "vtcl.tcl"
    bindtags $base "$base Vtcl.tcl all"
    vTcl:FireEvent $base <<Create>>
    }
    ###################
    # SETTING GEOMETRY
    ###################

    vTcl:FireEvent $base <<Ready>>
}

proc vTclWindow.top32 {base {container 0}} {
    if {$base == ""} {
        set base .top32
    }
    if {[winfo exists $base] && (!$container)} {
        wm deiconify $base; return
    }

    global widget
    vTcl:DefineAlias "$base" "Toplevel1" vTcl:Toplevel:WidgetProc "" 1
    vTcl:DefineAlias "$base.but37" "Button19" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra45" "Frame1" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra45.but32" "Button4" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra45.but48" "Button11" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra45.ent33" "Entry11" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra45.lab49" "Label4" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra45.scr47" "Scrollbar2" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra45.scr48" "Scrollbar1" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra45.tex46" "Text1" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra66" "Frame2" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra66.but51" "Button9" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra66.but52" "Button10" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra66.ent69" "Entry4" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra66.ent71" "Entry5" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra66.ent72" "Entry6" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra66.ent74" "Entry7" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra66.lab67" "Label5" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra66.lab70" "Label6" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra66.lab73" "Label7" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra66.lab75" "Label8" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra76" "Frame3" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra76.che97" "Checkbutton6" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra76.ent77" "Entry2" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra76.ent78" "Entry3" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra76.lab79" "Label2" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra76.lab79.ent37" "Entry1" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra76.lab80" "Label3" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra86" "Frame4" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra86.che95" "Checkbutton4" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra86.che96" "Checkbutton5" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra86.ent88" "Entry8" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra90" "Frame5" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra90.but32" "Button17" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra90.but34" "Button18" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra90.but41" "Button5" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra90.but49" "Button6" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra90.but50" "Button8" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra90.but91" "Button2" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra90.but93" "Button3" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra90.ent33" "Entry21" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra90.ent92" "Entry9" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra90.ent94" "Entry10" vTcl:WidgetProc "Toplevel1" 1

    ###################
    # CREATING WIDGETS
    ###################
    if {!$container} {
    vTcl:toplevel $base -class Toplevel \
        -menu "$base.m32" 
    wm focusmodel $base passive
    wm geometry $base 644x364+3+18; update
    wm maxsize $base 1009 738
    wm minsize $base 1 1
    wm overrideredirect $base 0
    wm resizable $base 0 0
    wm deiconify $base
    wm title $base "Chris's cdlabelgen Frontend"
    vTcl:FireEvent $base <<Create>>
    }
    frame $base.fra45 \
        -borderwidth 2 -cursor fleur -height 355 -relief groove -width 325 
    text $base.fra45.tex46 \
        -background white -height 284 -width 303 -wrap none \
        -xscrollcommand {Scrollbar2 set} -yscrollcommand {Scrollbar1 set} 
    scrollbar $base.fra45.scr47 \
        -command {Text1 xview} -orient horizontal -width 302 
    scrollbar $base.fra45.scr48 \
        -command {Text1 yview} -width 16 
    label $base.fra45.lab49 \
        -text {Item List} -width 58 
    button $base.fra45.but32 \
        \
        -command if\ \{\$import_list\ ==\ \"\"\}\\\n\{\n\ \ \ \ tk_messageBox\ -parent\ .\ -title\ \"Error\"\ -type\ \"ok\"\\\n\ \ \ \ \ \ \ \ -icon\ \"error\"\ -message\ \"You\ must\ enter\ a\ file\ to\ import\"\n\ \ \ \ return\n\}\n\nset\ fileid\ \[open\ \$import_list\]\nText1\ insert\ 1.0\ \[read\ -nonewline\ \$fileid\]\nclose\ \$fileid \
        -height 26 -text {Import File:} -width 89 
    entry $base.fra45.ent33 \
        -background white -textvariable import_list -width 198 
    button $base.fra45.but48 \
        \
        -command set\ temp\ \[tk_getOpenFile\ -initialdir\ \[pwd\]\\\n\ \ \ \ -filetypes\ \{\n\ \ \ \ \ \ \ \ \{\ \"All\ Files\"\ \{\ *\ \}\ \}\ \}\\\n\ \ \ \ -title\ \"Import\"\ -parent\ .\]\nif\ \{\$temp\ !=\ \"\"\}\\\n\{\n\ \ \ \ set\ import_list\ \$temp\n\} \
        -height 21 -text ... -width 22 
    frame $base.fra66 \
        -borderwidth 2 -height 90 -relief groove -width 305 
    label $base.fra66.lab67 \
        -text {Cover Image} 
    entry $base.fra66.ent69 \
        -background white -textvariable cover_image -width 168 
    label $base.fra66.lab70 \
        -height 0 -text {Cover Image Scale Ratio} 
    entry $base.fra66.ent71 \
        -background white -textvariable cover_image_sr -width 123 
    entry $base.fra66.ent72 \
        -background white -textvariable tray_image -width 168 
    label $base.fra66.lab73 \
        -height 0 -text {Tray Image} -width 0 
    entry $base.fra66.ent74 \
        -background white -textvariable tray_image_sr -width 123 
    label $base.fra66.lab75 \
        -text {Tray Image Scale Ratio} 
    button $base.fra66.but51 \
        \
        -command set\ temp\ \[tk_getOpenFile\ -initialdir\ \[pwd\]\\\n\ \ \ \ -filetypes\ \{\n\ \ \ \ \ \ \ \ \{\ \"EPS\ Files\"\ \{\ .eps\ .epsi\ .EPS\ .EPSI\ \}\ \}\n\ \ \ \ \ \ \ \ \{\ \"All\ Files\"\ \{\ *\ \}\ \}\ \}\\\n\ \ \ \ -title\ \"Open\"\ -parent\ .\]\nif\ \{\$temp\ !=\ \"\"\}\\\n\{\n\ \ \ \ set\ tray_image\ \$temp\n\} \
        -height 21 -text ... -width 22 
    button $base.fra66.but52 \
        \
        -command set\ temp\ \[tk_getOpenFile\ -initialdir\ \[pwd\]\\\n\ \ \ \ -filetypes\ \{\n\ \ \ \ \ \ \ \ \{\ \"EPS\ Files\"\ \{\ .eps\ .epsi\ .EPS\ .EPSI\ \}\ \}\n\ \ \ \ \ \ \ \ \{\ \"All\ Files\"\ \{\ *\ \}\ \}\ \}\\\n\ \ \ \ -title\ \"Open\"\ -parent\ .\]\nif\ \{\$temp\ !=\ \"\"\}\\\n\{\n\ \ \ \ set\ cover_image\ \$temp\n\} \
        -height 21 -text ... -width 22 
    frame $base.fra76 \
        -borderwidth 2 -height 75 -relief groove -width 305 
    entry $base.fra76.ent77 \
        -background white -cursor fleur -textvariable title -width 193 
    entry $base.fra76.ent78 \
        -background white -textvariable sub_title -width 193 
    label $base.fra76.lab79 \
        -height 0 -text Title -width 33 
    entry $base.fra76.lab79.ent37 \
        -background white -textvariable "$base\::ent37" 
    label $base.fra76.lab80 \
        -height 0 -text {Sub Title} -width 58 
    checkbutton $base.fra76.che97 \
        -height 22 -text {Show Plaque on Tray} -variable show_plaque \
        -width 153 
    frame $base.fra86 \
        -borderwidth 2 -cursor fleur -height 50 -relief groove -width 305 
    entry $base.fra86.ent88 \
        -background #ffffff -state normal -textvariable date -width 193 
    checkbutton $base.fra86.che95 \
        -text {Print Date} -variable print_date 
    checkbutton $base.fra86.che96 \
        -height 0 -text {Word Wrap} -variable word_wrap 
    frame $base.fra90 \
        -borderwidth 2 -height 95 -relief groove -width 305 
    button $base.fra90.but91 \
        \
        -command if\ \{\$title\ ==\ \"\"\}\\\n\{\n\ \ \ \ tk_messageBox\ -parent\ .\ -title\ \"Error\"\ -type\ \"ok\"\\\n\ \ \ \ \ \ \ \ -icon\ \"error\"\ -message\ \"You\ must\ enter\ a\ title\"\n\ \ \ \ return\n\}\ \ \nif\ \{\$sub_title\ ==\ \"\"\}\\\n\{\n\ \ \ \ tk_messageBox\ -parent\ .\ -title\ \"Error\"\ -type\ \"ok\"\\\n\ \ \ \ \ \ \ \ -icon\ \"error\"\ -message\ \"You\ must\ enter\ a\ sub\ title\"\n\ \ \ \ return\n\}\n\ \ \ \ \nset\ com_title\ \[clean\ \$title\]\nset\ com_sub_title\ \[clean\ \$sub_title\]\n\nset\ command\ \"cdlabelgen\ -c\ \\\"\$com_title\\\"\ -s\ \\\"\$com_sub_title\\\"\"\nif\ \{\$show_plaque\ ==\ 0\}\\\n\{\n\ \ \ \ append\ command\ \"\ -b\"\n\}\n#\ now\ done\ with\ plaque\n#\ on\ to\ item\ list\n\nset\ itemlist\ \[Text1\ get\ 1.0\ end\]\nset\ itemlist\ \[cleanitems\ \[clean\ \$itemlist\]\]\nappend\ command\ \"\ -i\ \\\"\$itemlist\\\"\"\n#\ now\ done\ with\ itemlist\n#\ on\ to\ images\n\nif\ \{\$cover_image\ !=\ \"\"\}\\\n\{\n\ \ \ \ append\ command\ \"\ -e\ \\\"\[clean\ \$cover_image\]\\\"\"\n\}\nif\ \{\$cover_image_sr\ !=\ \"\"\ &&\ \$cover_image_sr\ !=\ \"1\"\}\\\n\{\n\ \ \ \ append\ command\ \"\ -S\ \\\"\[clean\ \$cover_image_sr\]\\\"\"\n\}\nif\ \{\$tray_image\ !=\ \"\"\}\\\n\{\n\ \ \ \ append\ command\ \"\ -E\ \\\"\[clean\ \$tray_image\]\\\"\"\n\}\nif\ \{\$tray_image_sr\ !=\ \"\"\ &&\ \$tray_image_sr\ !=\ \"1\"\}\\\n\{\n\ \ \ \ append\ command\ \"\ -T\ \\\"\[clean\ \$tray_image_sr\]\\\"\"\n\}\n#\ done\ with\ images\n#\ on\ to\ date/wordwrap\n\nif\ \{\$print_date\ ==\ 0\}\\\n\{\n\ \ \ \ append\ command\ \"\ -D\"\n\}\nif\ \{\$print_date\ ==\ 1\ &&\ \$date\ !=\ \"\"\}\\\n\{\n\ \ \ \ append\ command\ \"\ -d\ \\\"\[clean\ \$date\]\\\"\"\n\}\nif\ \{\$word_wrap\ ==\ 1\}\\\n\{\n\ \ \ \ append\ command\ \"\ -w\"\n\}\n\nif\ \{\$preview_with\ ==\ \"\"\}\\\n\{\n\ \ \ \ tk_messageBox\ -parent\ .\ -title\ \"Error\"\ -type\ \"ok\"\\\n\ \ \ \ \ \ \ \ -icon\ \"error\"\ -message\ \"You\ must\ enter\ a\ program\ to\ preview\ with\"\n\ \ \ \ return\n\}\nappend\ command\ \"\ -o\ \\\"/tmp/cdlabelgenfe.ps\\\"\"\n\nset\ errorvar\ \"\"\n\nset\ fileid\ \[open\ |\$command\]\nset\ output\ \[read\ \$fileid\]\nif\ \{\$output\ !=\ \"\"\}\\\n\{\n\ \ \ \ tk_messageBox\ -parent\ .\ -title\ \"Error\"\ -type\ \"ok\"\\\n\ \ \ \ \ \ \ \ -icon\ \"error\"\ -message\ \"\$output\"\n\ \ \ \ return\n\}\n\neval\ exec\ \"\$preview_with\ \\\"/tmp/cdlabelgenfe.ps\\\"\" \
        -cursor fleur -height 26 -text {Preview With:} -width 100 
    entry $base.fra90.ent92 \
        -background white -textvariable preview_with -width 168 
    button $base.fra90.but93 \
        \
        -command if\ \{\$title\ ==\ \"\"\}\\\n\{\n\ \ \ \ tk_messageBox\ -parent\ .\ -title\ \"Error\"\ -type\ \"ok\"\\\n\ \ \ \ \ \ \ \ -icon\ \"error\"\ -message\ \"You\ must\ enter\ a\ title\"\n\ \ \ \ return\n\}\ \ \nif\ \{\$sub_title\ ==\ \"\"\}\\\n\{\n\ \ \ \ tk_messageBox\ -parent\ .\ -title\ \"Error\"\ -type\ \"ok\"\\\n\ \ \ \ \ \ \ \ -icon\ \"error\"\ -message\ \"You\ must\ enter\ a\ sub\ title\"\n\ \ \ \ return\n\}\n\ \ \ \ \nset\ com_title\ \[clean\ \$title\]\nset\ com_sub_title\ \[clean\ \$sub_title\]\n\nset\ command\ \"\$defpath\ -c\ \\\"\$com_title\\\"\ -s\ \\\"\$com_sub_title\\\"\"\nif\ \{\$show_plaque\ ==\ 0\}\\\n\{\n\ \ \ \ append\ command\ \"\ -b\"\n\}\n#\ now\ done\ with\ plaque\n#\ on\ to\ item\ list\n\nset\ itemlist\ \[Text1\ get\ 1.0\ end\]\nset\ itemlist\ \[cleanitems\ \[clean\ \$itemlist\]\]\nappend\ command\ \"\ -i\ \\\"\$itemlist\\\"\"\n#\ now\ done\ with\ itemlist\n#\ on\ to\ images\n\nif\ \{\$cover_image\ !=\ \"\"\}\\\n\{\n\ \ \ \ append\ command\ \"\ -e\ \\\"\[clean\ \$cover_image\]\\\"\"\n\}\nif\ \{\$cover_image_sr\ !=\ \"\"\ &&\ \$cover_image_sr\ !=\ \"1\"\}\\\n\{\n\ \ \ \ append\ command\ \"\ -S\ \\\"\[clean\ \$cover_image_sr\]\\\"\"\n\}\nif\ \{\$tray_image\ !=\ \"\"\}\\\n\{\n\ \ \ \ append\ command\ \"\ -E\ \\\"\[clean\ \$tray_image\]\\\"\"\n\}\nif\ \{\$tray_image_sr\ !=\ \"\"\ &&\ \$tray_image_sr\ !=\ \"1\"\}\\\n\{\n\ \ \ \ append\ command\ \"\ -T\ \\\"\[clean\ \$tray_image_sr\]\\\"\"\n\}\n#\ done\ with\ images\n#\ on\ to\ date/wordwrap\n\nif\ \{\$print_date\ ==\ 0\}\\\n\{\n\ \ \ \ append\ command\ \"\ -D\"\n\}\nif\ \{\$print_date\ ==\ 1\ &&\ \$date\ !=\ \"\"\}\\\n\{\n\ \ \ \ append\ command\ \"\ -d\ \\\"\[clean\ \$date\]\\\"\"\n\}\nif\ \{\$word_wrap\ ==\ 1\}\\\n\{\n\ \ \ \ append\ command\ \"\ -w\"\n\}\n\nif\ \{\$filename\ ==\ \"\"\}\\\n\{\n\ \ \ \ tk_messageBox\ -parent\ .\ -title\ \"Error\"\ -type\ \"ok\"\\\n\ \ \ \ \ \ \ \ -icon\ \"error\"\ -message\ \"You\ must\ enter\ a\ filename\ to\ save\ as\"\n\ \ \ \ return\n\}\n\nif\ \{\[file\ exists\ \$filename\]\}\\\n\{\n\ \ \ \ set\ confirm\ \[tk_messageBox\ -parent\ .\ -title\\\n\ \ \ \ \ \ \ \ \"Are\ you\ sure?\"\ -type\ yesno\ -icon\ \"question\"\\\n\ \ \ \ \ \ \ \ -message\ \"This\ file\ exits.\ \ Overwrite?\"\ -default\ \"no\"\]\n\ \ \ \ if\ \{\$confirm\ ==\ \"no\"\}\\\n\ \ \ \ \{\n\ \ \ \ \ \ \ \ return\n\ \ \ \ \}\n\}\n\nappend\ command\ \"\ -o\ \\\"\[clean\ \$filename\]\\\"\"\n\nset\ errorvar\ \"\"\n\nset\ fileid\ \[open\ |\$command\]\nset\ output\ \[read\ \$fileid\]\nif\ \{\$output\ !=\ \"\"\}\\\n\{\n\ \ \ \ tk_messageBox\ -parent\ .\ -title\ \"Error\"\ -type\ \"ok\"\\\n\ \ \ \ \ \ \ \ -icon\ \"error\"\ -message\ \"\$output\"\n\}\nif\ \{\$output\ ==\ \"\"\}\\\n\{\n\ \ \ \ tk_messageBox\ -parent\ .\ -title\ \"Success\"\ -type\ \"ok\"\\\n\ \ \ \ \ \ \ \ -icon\ \"info\"\ -message\ \"File\ Saved\"\n\} \
        -cursor fleur -text {Save to File:} 
    entry $base.fra90.ent94 \
        -background white -textvariable filename -width 168 
    button $base.fra90.but41 \
        -height 26 -text ... -width 22 
    button $base.fra90.but49 \
        \
        -command set\ temp\ \[tk_getSaveFile\ -initialdir\ \[pwd\]\\\n\ \ \ \ -filetypes\ \{\n\ \ \ \ \ \ \ \ \{\ \"Post\ Script\"\ \{\ .ps\ .PS\ \}\ \}\n\ \ \ \ \ \ \ \ \{\ \"All\ Files\"\ \{\ *\ \}\ \}\ \}\\\n\ \ \ \ -title\ \"Save\ to\ File\"\ -parent\ .\]\nif\ \{\$temp\ !=\ \"\"\}\\\n\{\n\ \ \ \ set\ filename\ \$temp\n\} \
        -height 21 -text ... -width 22 
    button $base.fra90.but50 \
        \
        -command set\ temp\ \[tk_getOpenFile\ -initialdir\ \[pwd\]\\\n\ \ \ \ -filetypes\ \{\n\ \ \ \ \ \ \ \ \{\ \"All\ Files\"\ \{\ *\ \}\ \}\ \}\\\n\ \ \ \ -title\ \"Open\"\ -parent\ .\]\nif\ \{\$temp\ !=\ \"\"\}\\\n\{\n\ \ \ \ set\ preview_with\ \$temp\n\} \
        -height 21 -text ... -width 22 
    button $base.fra90.but32 \
        \
        -command if\ \{\$title\ ==\ \"\"\}\\\n\{\n\ \ \ \ tk_messageBox\ -parent\ .\ -title\ \"Error\"\ -type\ \"ok\"\\\n\ \ \ \ \ \ \ \ -icon\ \"error\"\ -message\ \"You\ must\ enter\ a\ title\"\n\ \ \ \ return\n\}\ \ \nif\ \{\$sub_title\ ==\ \"\"\}\\\n\{\n\ \ \ \ tk_messageBox\ -parent\ .\ -title\ \"Error\"\ -type\ \"ok\"\\\n\ \ \ \ \ \ \ \ -icon\ \"error\"\ -message\ \"You\ must\ enter\ a\ sub\ title\"\n\ \ \ \ return\n\}\n\ \ \ \ \nset\ com_title\ \[clean\ \$title\]\nset\ com_sub_title\ \[clean\ \$sub_title\]\n\nset\ command\ \"cdlabelgen\ -c\ \\\"\$com_title\\\"\ -s\ \\\"\$com_sub_title\\\"\"\nif\ \{\$show_plaque\ ==\ 0\}\\\n\{\n\ \ \ \ append\ command\ \"\ -b\"\n\}\n#\ now\ done\ with\ plaque\n#\ on\ to\ item\ list\n\nset\ itemlist\ \[Text1\ get\ 1.0\ end\]\nset\ itemlist\ \[cleanitems\ \[clean\ \$itemlist\]\]\nappend\ command\ \"\ -i\ \\\"\$itemlist\\\"\"\n#\ now\ done\ with\ itemlist\n#\ on\ to\ images\n\nif\ \{\$cover_image\ !=\ \"\"\}\\\n\{\n\ \ \ \ append\ command\ \"\ -e\ \\\"\[clean\ \$cover_image\]\\\"\"\n\}\nif\ \{\$cover_image_sr\ !=\ \"\"\ &&\ \$cover_image_sr\ !=\ \"1\"\}\\\n\{\n\ \ \ \ append\ command\ \"\ -S\ \\\"\[clean\ \$cover_image_sr\]\\\"\"\n\}\nif\ \{\$tray_image\ !=\ \"\"\}\\\n\{\n\ \ \ \ append\ command\ \"\ -E\ \\\"\[clean\ \$tray_image\]\\\"\"\n\}\nif\ \{\$tray_image_sr\ !=\ \"\"\ &&\ \$tray_image_sr\ !=\ \"1\"\}\\\n\{\n\ \ \ \ append\ command\ \"\ -T\ \\\"\[clean\ \$tray_image_sr\]\\\"\"\n\}\n#\ done\ with\ images\n#\ on\ to\ date/wordwrap\n\nif\ \{\$print_date\ ==\ 0\}\\\n\{\n\ \ \ \ append\ command\ \"\ -D\"\n\}\nif\ \{\$print_date\ ==\ 1\ &&\ \$date\ !=\ \"\"\}\\\n\{\n\ \ \ \ append\ command\ \"\ -d\ \\\"\[clean\ \$date\]\\\"\"\n\}\nif\ \{\$word_wrap\ ==\ 1\}\\\n\{\n\ \ \ \ append\ command\ \"\ -w\"\n\}\n\nif\ \{\$preview_with\ ==\ \"\"\}\\\n\{\n\ \ \ \ tk_messageBox\ -parent\ .\ -title\ \"Error\"\ -type\ \"ok\"\\\n\ \ \ \ \ \ \ \ -icon\ \"error\"\ -message\ \"You\ must\ enter\ a\ program\ to\ preview\ with\"\n\ \ \ \ return\n\}\nappend\ command\ \"\ -o\ \\\"/tmp/cdlabelgenfe.ps\\\"\"\n\nset\ errorvar\ \"\"\n\nset\ fileid\ \[open\ |\$command\]\nset\ output\ \[read\ \$fileid\]\nif\ \{\$output\ !=\ \"\"\}\\\n\{\n\ \ \ \ tk_messageBox\ -parent\ .\ -title\ \"Error\"\ -type\ \"ok\"\\\n\ \ \ \ \ \ \ \ -icon\ \"error\"\ -message\ \"\$output\"\n\ \ \ \ return\n\}\n\neval\ exec\ \"\$print\ \\\"/tmp/cdlabelgenfe.ps\\\"\" \
        -cursor fleur -height 26 -text {Print Using:} -width 97 
    entry $base.fra90.ent33 \
        -background white -textvariable print -width 168 
    button $base.fra90.but34 \
        \
        -command set\ temp\ \[tk_getOpenFile\ -initialdir\ \[pwd\]\\\n\ \ \ \ -filetypes\ \{\n\ \ \ \ \ \ \ \ \{\ \"All\ Files\"\ \{\ *\ \}\ \}\ \}\\\n\ \ \ \ -title\ \"Open\"\ -parent\ .\]\nif\ \{\$temp\ !=\ \"\"\}\\\n\{\n\ \ \ \ set\ print\ \$temp\n\} \
        -cursor fleur -height 21 -text ... -width 22 
    menu $base.m32 \
        -tearoff 1 
    $base.m32 add cascade \
        -menu "$base.m32.men34" -accelerator {} -command {} -image {} \
        -label File 
    $base.m32 add cascade \
        -menu "$base.m32.men33" -accelerator {} -command {} -image {} \
        -label Commands 
    $base.m32 add cascade \
        -menu "$base.m32.men35" -accelerator {} -command {} -image {} \
        -label Help 
    menu $base.m32.men34 \
        -font [vTcl:font:get_font "vTcl:font1"] -tearoff 1 
    $base.m32.men34 add command \
        -accelerator {} -command {Toplevel2 show} -font {} -image {} \
        -label Preferences 
    $base.m32.men34 add separator
    $base.m32.men34 add command \
        -accelerator {} \
        -command #\ TODO:\ Your\ menu\ handler\ here\n#\ \n#\ open\ file\ dialog\nset\ temp\ \[tk_getSaveFile\ -initialdir\ \[pwd\]\\\n\ \ \ \ -filetypes\ \{\n\ \ \ \ \ \ \ \ \{\ \"All\ Files\"\ \{\ *\ \}\ \}\ \}\\\n\ \ \ \ -title\ \"Save\ to\ File\"\ -parent\ .\]\nif\ \{\$temp\ ==\ \"\"\}\\\n\{\n\ \ \ \ return\n\}\n\nset\ filename1\ \$temp\nset\ fileid\ \[open\ \$filename1\ w\]\n#\ put\ all\ data\ in\ file\nputs\ \$fileid\ \$show_plaque\nputs\ \$fileid\ \$title\nputs\ \$fileid\ \$sub_title\nputs\ \$fileid\ \$cover_image\nputs\ \$fileid\ \$cover_image_sr\nputs\ \$fileid\ \$tray_image\nputs\ \$fileid\ \$tray_image_sr\nputs\ \$fileid\ \$print_date\nputs\ \$fileid\ \$word_wrap\nputs\ \$fileid\ \$preview_with\nputs\ \$fileid\ \$filename\nputs\ \$fileid\ \$print\nputs\ -nonewline\ \$fileid\ \[Text1\ get\ 1.0\ end\]\nclose\ \$fileid\n\ntk_messageBox\ -parent\ .\ -title\ \"Success\"\ -type\ \"ok\"\\\n\ \ \ \ \ \ \ \ -icon\ \"info\"\ -message\ \"File\ Saved\" \
        -font {} -image {} -label {Save Data} 
    $base.m32.men34 add command \
        -accelerator {} \
        -command #\ TODO:\ Your\ menu\ handler\ here\n\nset\ temp\ \[tk_getOpenFile\ -initialdir\ \[pwd\]\\\n\ \ \ \ -filetypes\ \{\n\ \ \ \ \ \ \ \ \{\ \"All\ Files\"\ \{\ *\ \}\ \}\ \}\\\n\ \ \ \ -title\ \"Open\ File\"\ -parent\ .\]\nif\ \{\$temp\ ==\ \"\"\}\\\n\{\n\ \ \ \ return\n\}\n\nset\ filename1\ \$temp\nset\ fileid\ \[open\ \$filename1\ r\]\n#\ put\ all\ data\ in\ file\ngets\ \$fileid\ show_plaque\ngets\ \$fileid\ title\ngets\ \$fileid\ sub_title\ngets\ \$fileid\ cover_image\ngets\ \$fileid\ cover_image_sr\ngets\ \$fileid\ tray_image\ngets\ \$fileid\ tray_image_sr\ngets\ \$fileid\ print_date\ngets\ \$fileid\ word_wrap\ngets\ \$fileid\ preview_with\ngets\ \$fileid\ filename\ngets\ \$fileid\ print\nwhile\ \{\ 1\ \}\\\n\{\n\ \ \ \ gets\ \$fileid\ temp\n\ \ \ \ if\ \{\ \[string\ length\ \$temp\]\ ==\ 0\ \}\ \\\n\ \ \ \ \{\n\ \ \ \ \ \ \ \ Text1\ delete\ \[expr\ \[Text1\ index\ end\]-0.1\]\ end\n\ \ \ \ \ \ \ \ break\n\ \ \ \ \}\n\ \ \ \ Text1\ insert\ end\ \$temp\\n\n\}\ngets\ \$fileid\ \nclose\ \$fileid \
        -font {} -image {} -label {Load Data} 
    $base.m32.men34 add separator
    $base.m32.men34 add command \
        -accelerator {} \
        -command set\ answer\ \[tk_messageBox\ -parent\ .\ -type\ \"yesno\"\\\n\ \ \ \ -title\ \"Really?\"\ -icon\ \"question\"\\\n\ \ \ \ -message\ \"Really\ Quit?\"\ -default\ \"no\"\]\nif\ \{\$answer\ ==\ \"yes\"\}\\\n\{\n\ \ \ \ file\ delete\ -force\ \"/tmp/cdlabelgenfe.ps\"\n\ \ \ \ exit\n\} \
        -font {} -image {} -label Exit 
    menu $base.m32.men35 \
        -font [vTcl:font:get_font "vTcl:font1"] -tearoff 1 
    $base.m32.men35 add command \
        -accelerator {} \
        -command #\ TODO:\ Your\ menu\ handler\ here\ntk_messageBox\ -parent\ .\ -icon\ \"info\"\ -title\\\n\ \ \ \ \"About\"\ -type\ \"ok\"\ \\\n\ \ \ \ -message\ \"cdlabelgenfe\\nBy\ Chris\ Black\\nblackc@andrews.edu\\nv0.3\" \
        -font {} -image {} -label About 
    menu $base.m32.men33 \
        -font [vTcl:font:get_font "vTcl:font1"] -tearoff 1 
    $base.m32.men33 add command \
        -accelerator {} \
        -command #\ TODO:\ Your\ menu\ handler\ here\nset\ confirm\ \[tk_messageBox\ -parent\ .\ -title\\\n\ \ \ \ \"Are\ you\ sure?\"\ -type\ yesno\ -icon\ \"question\"\\\n\ \ \ \ -message\ \"Really\ clear\ Item\ List?\"\ -default\ \"no\"\]\nif\ \{\$confirm\ ==\ \"no\"\}\\\n\{\n\ \ \ \ return\n\}\n\nText1\ delete\ 1.0\ end \
        -font {} -image {} -label {Clear Item List} 
    $base.m32.men33 add command \
        -accelerator {} \
        -command set\ confirm\ \[tk_messageBox\ -parent\ .\ -title\\\n\ \ \ \ \"Are\ you\ sure?\"\ -type\ yesno\ -icon\ \"question\"\\\n\ \ \ \ -message\ \"Really\ clear\ all\ fields?\"\ -default\ \"no\"\]\nif\ \{\$confirm\ ==\ \"no\"\}\\\n\{\n\ \ \ \ return\n\}\n\nText1\ delete\ 1.0\ end\nEntry11\ delete\ 0\ end\nEntry2\ delete\ 0\ end\nEntry3\ delete\ 0\ end\nEntry4\ delete\ 0\ end\nEntry5\ delete\ 0\ end\nEntry6\ delete\ 0\ end\nEntry7\ delete\ 0\ end\nEntry9\ delete\ 0\ end\nEntry10\ delete\ 0\ end\nEntry21\ delete\ 0\ end \
        -font {} -image {} -label {Clear All Fields} 
    button $base.but37 \
        \
        -command set\ answer\ \[tk_messageBox\ -parent\ .\ -type\ \"yesno\"\\\n\ \ \ \ -title\ \"Really?\"\ -icon\ \"question\"\\\n\ \ \ \ -message\ \"Really\ Quit?\"\ -default\ \"no\"\]\nif\ \{\$answer\ ==\ \"yes\"\}\\\n\{\n\ \ \ \ file\ delete\ -force\ \"/tmp/cdlabelgenfe.ps\"\n\ \ \ \ exit\n\} \
        -cursor fleur -height 26 -text Exit -width 67 
    ###################
    # SETTING GEOMETRY
    ###################
    place $base.fra45 \
        -x 5 -y 5 -width 325 -height 355 -anchor nw -bordermode ignore 
    place $base.fra45.tex46 \
        -x 5 -y 25 -width 303 -height 284 -anchor nw -bordermode ignore 
    place $base.fra45.scr47 \
        -x 5 -y 305 -width 302 -height 16 -anchor nw -bordermode ignore 
    place $base.fra45.scr48 \
        -x 305 -y 25 -width 16 -height 282 -anchor nw -bordermode ignore 
    place $base.fra45.lab49 \
        -x 155 -y 15 -width 58 -height 20 -anchor center -bordermode ignore 
    place $base.fra45.but32 \
        -x 5 -y 325 -width 89 -height 26 -anchor nw -bordermode ignore 
    place $base.fra45.ent33 \
        -x 100 -y 325 -width 198 -height 22 -anchor nw -bordermode ignore 
    place $base.fra45.but48 \
        -x 300 -y 325 -width 22 -height 21 -anchor nw -bordermode ignore 
    place $base.fra66 \
        -x 335 -y 85 -width 305 -height 90 -anchor nw -bordermode ignore 
    place $base.fra66.lab67 \
        -x 5 -y 5 -anchor nw -bordermode ignore 
    place $base.fra66.ent69 \
        -x 105 -y 5 -width 168 -height 22 -anchor nw -bordermode ignore 
    place $base.fra66.lab70 \
        -x 5 -y 25 -anchor nw -bordermode ignore 
    place $base.fra66.ent71 \
        -x 180 -y 25 -width 123 -height 22 -anchor nw -bordermode ignore 
    place $base.fra66.ent72 \
        -x 110 -y 45 -width 168 -height 22 -anchor nw -bordermode ignore 
    place $base.fra66.lab73 \
        -x 5 -y 45 -anchor nw -bordermode ignore 
    place $base.fra66.ent74 \
        -x 180 -y 65 -width 123 -height 22 -anchor nw -bordermode ignore 
    place $base.fra66.lab75 \
        -x 5 -y 65 -anchor nw -bordermode ignore 
    place $base.fra66.but51 \
        -x 280 -y 45 -width 22 -height 21 -anchor nw -bordermode ignore 
    place $base.fra66.but52 \
        -x 280 -y 5 -width 22 -height 21 -anchor nw -bordermode ignore 
    place $base.fra76 \
        -x 335 -y 5 -width 305 -height 75 -anchor nw -bordermode ignore 
    place $base.fra76.ent77 \
        -x 110 -y 30 -width 193 -height 22 -anchor nw -bordermode ignore 
    place $base.fra76.ent78 \
        -x 110 -y 50 -width 193 -height 22 -anchor nw -bordermode ignore 
    place $base.fra76.lab79 \
        -x 5 -y 30 -width 33 -height 20 -anchor nw -bordermode ignore 
    place $base.fra76.lab79.ent37 \
        -x 62 -y 5 -anchor nw -bordermode ignore 
    place $base.fra76.lab80 \
        -x 5 -y 50 -width 58 -height 20 -anchor nw -bordermode ignore 
    place $base.fra76.che97 \
        -x 5 -y 5 -width 153 -height 22 -anchor nw -bordermode ignore 
    place $base.fra86 \
        -x 335 -y 180 -width 305 -height 50 -anchor nw -bordermode ignore 
    place $base.fra86.ent88 \
        -x 110 -y 5 -width 193 -height 22 -anchor nw -bordermode ignore 
    place $base.fra86.che95 \
        -x 5 -y 5 -anchor nw -bordermode ignore 
    place $base.fra86.che96 \
        -x 5 -y 25 -anchor nw -bordermode ignore 
    place $base.fra90 \
        -x 335 -y 235 -width 305 -height 95 -anchor nw -bordermode ignore 
    place $base.fra90.but91 \
        -x 5 -y 5 -width 100 -height 26 -anchor nw -bordermode ignore 
    place $base.fra90.ent92 \
        -x 110 -y 5 -width 168 -height 22 -anchor nw -bordermode ignore 
    place $base.fra90.but93 \
        -x 5 -y 35 -anchor nw -bordermode ignore 
    place $base.fra90.ent94 \
        -x 110 -y 35 -width 168 -height 22 -anchor nw -bordermode ignore 
    place $base.fra90.but41 \
        -x 46 -y 188 -anchor nw 
    place $base.fra90.but49 \
        -x 280 -y 35 -width 22 -height 21 -anchor nw -bordermode ignore 
    place $base.fra90.but50 \
        -x 280 -y 5 -width 22 -height 21 -anchor nw -bordermode ignore 
    place $base.fra90.but32 \
        -x 5 -y 65 -width 97 -height 26 -anchor nw -bordermode ignore 
    place $base.fra90.ent33 \
        -x 110 -y 65 -width 168 -height 22 -anchor nw -bordermode ignore 
    place $base.fra90.but34 \
        -x 280 -y 65 -width 22 -height 21 -anchor nw -bordermode ignore 
    place $base.but37 \
        -x 575 -y 335 -width 67 -height 26 -anchor nw -bordermode ignore 

    vTcl:FireEvent $base <<Ready>>
}

proc vTclWindow.top38 {base {container 0}} {
    if {$base == ""} {
        set base .top38
    }
    if {[winfo exists $base] && (!$container)} {
        wm deiconify $base; return
    }

    global widget
    vTcl:DefineAlias "$base" "Toplevel2" vTcl:Toplevel:WidgetProc "" 1
    vTcl:DefineAlias "$base.but45" "Button13" vTcl:WidgetProc "Toplevel2" 1
    vTcl:DefineAlias "$base.but53" "Button14" vTcl:WidgetProc "Toplevel2" 1
    vTcl:DefineAlias "$base.but54" "Button15" vTcl:WidgetProc "Toplevel2" 1
    vTcl:DefineAlias "$base.but71" "Button16" vTcl:WidgetProc "Toplevel2" 1
    vTcl:DefineAlias "$base.ent36" "Entry22" vTcl:WidgetProc "Toplevel2" 1
    vTcl:DefineAlias "$base.ent42" "Entry12" vTcl:WidgetProc "Toplevel2" 1
    vTcl:DefineAlias "$base.ent44" "Entry13" vTcl:WidgetProc "Toplevel2" 1
    vTcl:DefineAlias "$base.ent56" "Entry14" vTcl:WidgetProc "Toplevel2" 1
    vTcl:DefineAlias "$base.fra47" "Frame6" vTcl:WidgetProc "Toplevel2" 1
    vTcl:DefineAlias "$base.fra47.che48" "Checkbutton7" vTcl:WidgetProc "Toplevel2" 1
    vTcl:DefineAlias "$base.fra47.che50" "Checkbutton8" vTcl:WidgetProc "Toplevel2" 1
    vTcl:DefineAlias "$base.fra47.che51" "Checkbutton9" vTcl:WidgetProc "Toplevel2" 1
    vTcl:DefineAlias "$base.fra47.ent60" "Entry15" vTcl:WidgetProc "Toplevel2" 1
    vTcl:DefineAlias "$base.fra47.ent66" "Entry16" vTcl:WidgetProc "Toplevel2" 1
    vTcl:DefineAlias "$base.fra47.ent67" "Entry17" vTcl:WidgetProc "Toplevel2" 1
    vTcl:DefineAlias "$base.fra47.ent68" "Entry18" vTcl:WidgetProc "Toplevel2" 1
    vTcl:DefineAlias "$base.fra47.ent69" "Entry19" vTcl:WidgetProc "Toplevel2" 1
    vTcl:DefineAlias "$base.fra47.ent70" "Entry20" vTcl:WidgetProc "Toplevel2" 1
    vTcl:DefineAlias "$base.fra47.lab58" "Label14" vTcl:WidgetProc "Toplevel2" 1
    vTcl:DefineAlias "$base.fra47.lab61" "Label16" vTcl:WidgetProc "Toplevel2" 1
    vTcl:DefineAlias "$base.fra47.lab62" "Label17" vTcl:WidgetProc "Toplevel2" 1
    vTcl:DefineAlias "$base.fra47.lab63" "Label18" vTcl:WidgetProc "Toplevel2" 1
    vTcl:DefineAlias "$base.fra47.lab64" "Label19" vTcl:WidgetProc "Toplevel2" 1
    vTcl:DefineAlias "$base.fra47.lab65" "Label20" vTcl:WidgetProc "Toplevel2" 1
    vTcl:DefineAlias "$base.lab35" "Label21" vTcl:WidgetProc "Toplevel2" 1
    vTcl:DefineAlias "$base.lab41" "Label10" vTcl:WidgetProc "Toplevel2" 1
    vTcl:DefineAlias "$base.lab43" "Label11" vTcl:WidgetProc "Toplevel2" 1
    vTcl:DefineAlias "$base.lab52" "Label12" vTcl:WidgetProc "Toplevel2" 1
    vTcl:DefineAlias "$base.lab55" "Label13" vTcl:WidgetProc "Toplevel2" 1

    ###################
    # CREATING WIDGETS
    ###################
    if {!$container} {
    vTcl:toplevel $base -class Toplevel \
        -menu "$base.m39" 
    wm withdraw $base
    wm focusmodel $base passive
    wm geometry $base 360x322+199+125; update
    wm maxsize $base 1009 738
    wm minsize $base 1 1
    wm overrideredirect $base 0
    wm resizable $base 0 0
    wm title $base "Preferences"
    vTcl:FireEvent $base <<Create>>
    }
    menu $base.m39 \
        -tearoff 1 
    label $base.lab41 \
        -height 0 -text {cdlabelgen Path:} -width 103 
    entry $base.ent42 \
        -background white -textvariable defpath -width 228 
    label $base.lab43 \
        -height 0 -text {Preview Program:} -width 0 
    entry $base.ent44 \
        -background white -textvariable defpreview_with -width 228 
    button $base.but45 \
        \
        -command {set olddir [pwd]
cd ~
file delete -force ".cdlabelgenfe"
file mkdir ".cdlabelgenfe"
set fileid [open "[pwd]/.cdlabelgenfe/config" "CREAT WRONLY TRUNC"]
puts $fileid $defpath
puts $fileid $defpreview_with
puts $fileid $defsave_dir
puts $fileid $defshow_plaque
puts $fileid $defword_wrap
puts $fileid $defprint_date
puts $fileid $deftitle
puts $fileid $defsub_title
puts $fileid $defcover_image
puts $fileid $defcover_image_sr
puts $fileid $deftray_image
puts $fileid $deftray_image_sr
puts $fileid $defprint
close $fileid
cd $olddir

Toplevel2 hide} \
        -cursor fleur -height 0 -text Done 
    frame $base.fra47 \
        -borderwidth 2 -cursor fleur -height 180 -relief groove -width 350 
    checkbutton $base.fra47.che48 \
        -height 0 -text {Show Plaque on Tray} -variable defshow_plaque 
    checkbutton $base.fra47.che50 \
        -command {} -text {Print Date} -variable defprint_date 
    checkbutton $base.fra47.che51 \
        -height 0 -text {Word Wrap} -variable defword_wrap 
    label $base.fra47.lab58 \
        -cursor fleur -text Title 
    entry $base.fra47.ent60 \
        -background white -textvariable deftitle -width 218 
    label $base.fra47.lab61 \
        -text {Sub Title} 
    label $base.fra47.lab62 \
        -text {Cover Image} 
    label $base.fra47.lab63 \
        -text {Cover Image Scale} 
    label $base.fra47.lab64 \
        -text {Tray Image} 
    label $base.fra47.lab65 \
        -text {Tray Image Scale} 
    entry $base.fra47.ent66 \
        -background white -textvariable defsub_title -width 218 
    entry $base.fra47.ent67 \
        -background white -textvariable defcover_image -width 218 
    entry $base.fra47.ent68 \
        -background white -textvariable defcover_image_sr -width 218 
    entry $base.fra47.ent69 \
        -background white -textvariable deftray_image -width 218 
    entry $base.fra47.ent70 \
        -background white -textvariable deftray_image_sr -width 218 
    label $base.lab52 \
        -text Defaults 
    button $base.but53 \
        \
        -command Entry12\ delete\ 0\ end\nEntry13\ delete\ 0\ end\nEntry14\ delete\ 0\ end\nEntry15\ delete\ 0\ end\nEntry16\ delete\ 0\ end\nEntry17\ delete\ 0\ end\nEntry18\ delete\ 0\ end\nEntry19\ delete\ 0\ end\nEntry20\ delete\ 0\ end\nEntry22\ delete\ 0\ end\n\ncd\ \"~\"\nset\ mydir\ \[pwd\]\nappend\ mydir\ \"/\"\nEntry14\ insert\ 0\ \$mydir\nEntry12\ insert\ 0\ \"/usr/bin/cdlabelgen\"\nEntry13\ insert\ 0\ \"/usr/X11R6/bin/gv\"\nEntry17\ insert\ 0\ \"penguin.eps\"\nEntry18\ insert\ 0\ \"0.5\"\nEntry22\ insert\ 0\ \"/usr/bin/lpr\"\n\nif\ \{\$defshow_plaque\ ==\ 0\}\\\n\{\n\ \ \ \ Checkbutton7\ invoke\n\}\nif\ \{\$defprint_date\ ==\ 0\}\\\n\{\n\ \ \ \ Checkbutton8\ invoke\n\}\nif\ \{\$defword_wrap\ ==\ 1\}\\\n\{\n\ \ \ \ Checkbutton9\ invoke\n\} \
        -cursor fleur -height 0 -text Defaults 
    button $base.but54 \
        \
        -command set\ olddir\ \[pwd\]\ncd\ ~\n\nif\ \{\[file\ exists\ \".cdlabelgenfe/config\"\]\ ==\ 0\}\\\n\{\n\ \ \ \ Entry12\ delete\ 0\ end\n\ \ \ \ Entry13\ delete\ 0\ end\n\ \ \ \ Entry14\ delete\ 0\ end\n\ \ \ \ Entry15\ delete\ 0\ end\n\ \ \ \ Entry16\ delete\ 0\ end\n\ \ \ \ Entry17\ delete\ 0\ end\n\ \ \ \ Entry18\ delete\ 0\ end\n\ \ \ \ Entry19\ delete\ 0\ end\n\ \ \ \ Entry20\ delete\ 0\ end\n\ \ \ \ Entry22\ delete\ 0\ end\n\ \ \ \ \n\ \ \ \ cd\ \"~\"\n\ \ \ \ set\ mydir\ \[pwd\]\n\ \ \ \ append\ mydir\ \"/\"\n\ \ \ \ Entry14\ insert\ 0\ \$mydir\n\ \ \ \ Entry12\ insert\ 0\ \"/usr/bin/cdlabelgen/\"\n\ \ \ \ Entry13\ insert\ 0\ \"/usr/X11R6/bin/gv\"\n\ \ \ \ Entry17\ insert\ 0\ \"penguin.eps\"\n\ \ \ \ Entry18\ insert\ 0\ \"0.5\"\n\ \ \ \ Entry22\ insert\ 0\ \"/usr/bin/lpr\"\n\n\ \ \ \ if\ \{\$defshow_plaque\ ==\ 0\}\\\n\ \ \ \ \{\n\ \ \ \ \ \ \ \ Checkbutton7\ invoke\n\ \ \ \ \}\n\ \ \ \ if\ \{\$defprint_date\ ==\ 0\}\\\n\ \ \ \ \{\n\ \ \ \ \ \ \ \ Checkbutton8\ invoke\n\ \ \ \ \}\n\ \ \ \ if\ \{\$defword_wrap\ ==\ 1\}\\\n\ \ \ \ \{\n\ \ \ \ \ \ \ \ Checkbutton9\ invoke\n\ \ \ \ \}\n\ \ \ \ cd\ \$olddir\n\ \ \ \ return\n\}\n\n#read\ in\ file\nEntry12\ delete\ 0\ end\nEntry13\ delete\ 0\ end\nEntry14\ delete\ 0\ end\nEntry15\ delete\ 0\ end\nEntry16\ delete\ 0\ end\nEntry17\ delete\ 0\ end\nEntry18\ delete\ 0\ end\nEntry19\ delete\ 0\ end\nEntry20\ delete\ 0\ end\nEntry22\ delete\ 0\ end\n\nset\ fileid\ \[open\ \".cdlabelgenfe/config\"\]\ngets\ \$fileid\ defpath\ngets\ \$fileid\ defpreview_with\ngets\ \$fileid\ defsave_dir\ngets\ \$fileid\ defshow_plaque\ngets\ \$fileid\ defword_wrap\ngets\ \$fileid\ defprint_date\ngets\ \$fileid\ deftitle\ngets\ \$fileid\ defsub_title\ngets\ \$fileid\ defcover_image\ngets\ \$fileid\ defcover_image_sr\ngets\ \$fileid\ deftray_image\ngets\ \$fileid\ deftray_image_sr\ngets\ \$fileid\ defprint\nclose\ \$fileid\n\ncd\ \$olddir\n\nToplevel2\ hide \
        -cursor fleur -height 0 -text Cancel 
    label $base.lab55 \
        -text {Initial Save Dir} 
    entry $base.ent56 \
        -background white -textvariable defsave_dir -width 228 
    button $base.but71 \
        \
        -command Entry2\ delete\ 0\ end\nEntry3\ delete\ 0\ end\nEntry4\ delete\ 0\ end\nEntry5\ delete\ 0\ end\nEntry6\ delete\ 0\ end\nEntry7\ delete\ 0\ end\nEntry9\ delete\ 0\ end\nEntry10\ delete\ 0\ end\nEntry21\ delete\ 0\ end\n\nEntry2\ insert\ 0\ \$deftitle\nEntry3\ insert\ 0\ \$defsub_title\nEntry4\ insert\ 0\ \$defcover_image\nEntry5\ insert\ 0\ \$defcover_image_sr\nEntry6\ insert\ 0\ \$deftray_image\nEntry7\ insert\ 0\ \$deftray_image_sr\nEntry9\ insert\ 0\ \$defpreview_with\nEntry10\ insert\ 0\ \$defsave_dir\nEntry10\ insert\ end\ untitled.ps\nEntry21\ insert\ 0\ \$defprint\n\nif\ \{\$defshow_plaque\ ==\ 1\ &&\ \$show_plaque\ ==\ 0\}\\\n\{\n\ \ \ \ Checkbutton6\ invoke\n\}\nif\ \{\$defshow_plaque\ ==\ 0\ &&\ \$show_plaque\ ==\ 1\}\\\n\{\n\ \ \ \ Checkbutton6\ invoke\n\}\n\nif\ \{\$defword_wrap\ ==\ 1\ &&\ \$word_wrap\ ==\ 0\}\\\n\{\n\ \ \ \ Checkbutton5\ invoke\n\}\nif\ \{\$defword_wrap\ ==\ 0\ &&\ \$word_wrap\ ==\ 1\}\\\n\{\n\ \ \ \ Checkbutton5\ invoke\n\}\n\nif\ \{\$defprint_date\ ==\ 1\ &&\ \$print_date\ ==\ 0\}\\\n\{\n\ \ \ \ Checkbutton4\ invoke\n\}\nif\ \{\$defprint_date\ ==\ 0\ &&\ \$print_date\ ==\ 1\}\\\n\{\n\ \ \ \ Checkbutton4\ invoke\n\}\n\nset\ olddir\ \[pwd\]\ncd\ ~\nfile\ delete\ -force\ \".cdlabelgenfe\"\nfile\ mkdir\ \".cdlabelgenfe\"\nset\ fileid\ \[open\ \"\[pwd\]/.cdlabelgenfe/config\"\ \"CREAT\ WRONLY\ TRUNC\"\]\nputs\ \$fileid\ \$defpath\nputs\ \$fileid\ \$defpreview_with\nputs\ \$fileid\ \$defsave_dir\nputs\ \$fileid\ \$defshow_plaque\nputs\ \$fileid\ \$defword_wrap\nputs\ \$fileid\ \$defprint_date\nputs\ \$fileid\ \$deftitle\nputs\ \$fileid\ \$defsub_title\nputs\ \$fileid\ \$defcover_image\nputs\ \$fileid\ \$defcover_image_sr\nputs\ \$fileid\ \$deftray_image\nputs\ \$fileid\ \$deftray_image_sr\nclose\ \$fileid\ncd\ \$olddir \
        -cursor fleur -height 0 -text Apply 
    label $base.lab35 \
        -height 0 -text {Print Command:} -width 98 
    entry $base.ent36 \
        -background white -textvariable defprint -width 228 
    ###################
    # SETTING GEOMETRY
    ###################
    place $base.lab41 \
        -x 5 -y 5 -width 103 -height 20 -anchor nw -bordermode ignore 
    place $base.ent42 \
        -x 125 -y 5 -width 228 -height 22 -anchor nw -bordermode ignore 
    place $base.lab43 \
        -x 5 -y 30 -anchor nw -bordermode ignore 
    place $base.ent44 \
        -x 125 -y 30 -width 228 -height 22 -anchor nw -bordermode ignore 
    place $base.but45 \
        -x 305 -y 295 -anchor nw -bordermode ignore 
    place $base.fra47 \
        -x 5 -y 110 -width 350 -height 180 -anchor nw -bordermode ignore 
    place $base.fra47.che48 \
        -x 5 -y 5 -anchor nw -bordermode ignore 
    place $base.fra47.che50 \
        -x 250 -y 5 -anchor nw -bordermode ignore 
    place $base.fra47.che51 \
        -x 160 -y 5 -anchor nw -bordermode ignore 
    place $base.fra47.lab58 \
        -x 5 -y 25 -anchor nw -bordermode ignore 
    place $base.fra47.ent60 \
        -x 125 -y 25 -width 218 -height 22 -anchor nw -bordermode ignore 
    place $base.fra47.lab61 \
        -x 5 -y 50 -anchor nw -bordermode ignore 
    place $base.fra47.lab62 \
        -x 5 -y 75 -anchor nw -bordermode ignore 
    place $base.fra47.lab63 \
        -x 5 -y 100 -anchor nw -bordermode ignore 
    place $base.fra47.lab64 \
        -x 5 -y 125 -anchor nw -bordermode ignore 
    place $base.fra47.lab65 \
        -x 5 -y 150 -anchor nw -bordermode ignore 
    place $base.fra47.ent66 \
        -x 125 -y 50 -width 218 -height 22 -anchor nw -bordermode ignore 
    place $base.fra47.ent67 \
        -x 125 -y 75 -width 218 -height 22 -anchor nw -bordermode ignore 
    place $base.fra47.ent68 \
        -x 125 -y 100 -width 218 -height 22 -anchor nw -bordermode ignore 
    place $base.fra47.ent69 \
        -x 125 -y 125 -width 218 -height 22 -anchor nw -bordermode ignore 
    place $base.fra47.ent70 \
        -x 125 -y 150 -width 218 -height 22 -anchor nw -bordermode ignore 
    place $base.lab52 \
        -x 15 -y 100 -anchor nw -bordermode ignore 
    place $base.but53 \
        -x 105 -y 295 -anchor nw -bordermode ignore 
    place $base.but54 \
        -x 240 -y 295 -anchor nw -bordermode ignore 
    place $base.lab55 \
        -x 5 -y 55 -anchor nw -bordermode ignore 
    place $base.ent56 \
        -x 125 -y 55 -width 228 -height 22 -anchor nw -bordermode ignore 
    place $base.but71 \
        -x 180 -y 295 -anchor nw -bordermode ignore 
    place $base.lab35 \
        -x 5 -y 80 -width 98 -height 20 -anchor nw -bordermode ignore 
    place $base.ent36 \
        -x 125 -y 80 -width 228 -height 22 -anchor nw -bordermode ignore 

    vTcl:FireEvent $base <<Ready>>
}

Window show .
Window show .top32
Window show .top38

main $argc $argv
